#[repr(C)]pub struct Money {
pub raw: MoneyRaw,
pub currency: Currency,
}Expand description
Fields
raw: MoneyRawRepresents the raw fixed-point amount, with currency.precision defining the number of decimal places.
currency: CurrencyThe currency denomination associated with the monetary amount.
Implementations
Sourceimpl Money
impl Money
Sourcepub fn new_checked(amount: f64, currency: Currency) -> Result<Self>
pub fn new_checked(amount: f64, currency: Currency) -> Result<Self>
Sourcepub fn new(amount: f64, currency: Currency) -> Self
pub fn new(amount: f64, currency: Currency) -> Self
Creates a new Money instance.
Panics
Panics if a correctness check fails. See Money::new_checked for more details.
Sourcepub fn from_raw(raw: MoneyRaw, currency: Currency) -> Self
pub fn from_raw(raw: MoneyRaw, currency: Currency) -> Self
Creates a new Money instance from the given raw fixed-point value and the specified currency.
Panics
Panics if raw is outside the representable range [MONEY_RAW_MIN, MONEY_RAW_MAX].
Panics if currency.precision exceeds FIXED_PRECISION.
Sourcepub fn zero(currency: Currency) -> Self
pub fn zero(currency: Currency) -> Self
Creates a new Money instance with a value of zero with the given Currency.
Panics
Panics if a correctness check fails. See Money::new_checked for more details.
Sourcepub fn as_f64(&self) -> f64
pub fn as_f64(&self) -> f64
Returns the value of this instance as an f64.
Panics
Panics if precision is beyond MAX_FLOAT_PRECISION (16).
Sourcepub fn as_decimal(&self) -> Decimal
pub fn as_decimal(&self) -> Decimal
Returns the value of this instance as a Decimal.
Sourcepub fn to_formatted_string(&self) -> String
pub fn to_formatted_string(&self) -> String
Returns a formatted string representation of this instance.
Sourcepub fn from_decimal(decimal: Decimal, currency: Currency) -> Result<Self>
pub fn from_decimal(decimal: Decimal, currency: Currency) -> Result<Self>
Creates a new Money from a Decimal value with specified currency.
This method provides more reliable parsing by using Decimal arithmetic to avoid floating-point precision issues during conversion.
Errors
Returns an error if:
- The decimal value cannot be converted to the raw representation.
- Overflow occurs during scaling.
Sourceimpl Money
impl Money
Sourcepub fn from_wei<U>(raw_wei: U, currency: Currency) -> Selfwhere
U: Into<U256>,
pub fn from_wei<U>(raw_wei: U, currency: Currency) -> Selfwhere
U: Into<U256>,
Creates a new Money instance from raw wei value with 18-decimal precision.
This method is specifically designed for DeFi applications where values are represented in wei (the smallest unit of Ether, 1 ETH = 10^18 wei).
Panics
Panics if the raw wei value exceeds 128-bit range.
Examples
use nautilus_model::types::{Money, Currency};
use nautilus_model::enums::CurrencyType;
use alloy_primitives::U256;
use rust_decimal_macros::dec;
let eth = Currency::new("ETH", 18, 0, "Ethereum", CurrencyType::Crypto);
let money = Money::from_wei(U256::from(1_000_000_000_000_000_000_u64), eth); // 1 ETH
assert_eq!(money.as_decimal(), dec!(1.0));Sourcepub fn to_wei(&self) -> U256
pub fn to_wei(&self) -> U256
Converts this Money instance to raw wei value.
Only valid for prices with precision 18. For other precisions convert to precision 18 first.
Returns
The raw wei value as a U256.
Examples
use nautilus_model::types::{Money, Currency};
use nautilus_model::enums::CurrencyType;
use alloy_primitives::U256;
let eth = Currency::new("ETH", 18, 0, "Ethereum", CurrencyType::Crypto);
// Construct via raw wei to ensure correct 18-dec precision.
let money = Money::from_wei(U256::from(1_000_000_000_000_000_000_u64), eth); // 1 ETH
let wei_value = money.to_wei();
assert_eq!(wei_value, U256::from(1_000_000_000_000_000_000_u64));Trait Implementations
Sourceimpl AddAssign for Money
impl AddAssign for Money
Sourcefn add_assign(&mut self, other: Self)
fn add_assign(&mut self, other: Self)
+= operation. Read moreSourceimpl<'de> Deserialize<'de> for Money
impl<'de> Deserialize<'de> for Money
Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Sourceimpl<'py> IntoPyObject<'py> for Money
impl<'py> IntoPyObject<'py> for Money
Sourceimpl Ord for Money
impl Ord for Money
Sourceimpl PartialOrd for Money
impl PartialOrd for Money
Sourceimpl PyClassImpl for Money
impl PyClassImpl for Money
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
Sourceconst RAW_DOC: &'static CStr = /// Represents an amount of money in a specified currency denomination.
///
/// - [`MONEY_MAX`] - Maximum representable money amount
/// - [`MONEY_MIN`] - Minimum representable money amount
const RAW_DOC: &'static CStr = /// Represents an amount of money in a specified currency denomination. /// /// - [`MONEY_MAX`] - Maximum representable money amount /// - [`MONEY_MIN`] - Minimum representable money amount
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
text_signature if a constructor is defined. Read moreSourcetype ThreadChecker = SendablePyClass<Money>
type ThreadChecker = SendablePyClass<Money>
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::ImmutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::ImmutableChild
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<isize>
fn weaklist_offset() -> Option<isize>
Sourceimpl PyClassNewTextSignature for Money
impl PyClassNewTextSignature for Money
const TEXT_SIGNATURE: &'static str = "(amount, currency)"
Sourceimpl PyMethods<Money> for PyClassImplCollector<Money>
impl PyMethods<Money> for PyClassImplCollector<Money>
fn py_methods(self) -> &'static PyClassItems
Sourceimpl PyTypeInfo for Money
impl PyTypeInfo for Money
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
object is an instance of this type or a subclass of this type.fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
object is an instance of this type.Sourceimpl SubAssign for Money
impl SubAssign for Money
Sourcefn sub_assign(&mut self, other: Self)
fn sub_assign(&mut self, other: Self)
-= operation. Read moreimpl Copy for Money
impl DerefToPyAny for Money
impl Eq for Money